summaryrefslogtreecommitdiffstats
path: root/kjsembed/slotutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/slotutils.h')
-rw-r--r--kjsembed/slotutils.h108
1 files changed, 54 insertions, 54 deletions
diff --git a/kjsembed/slotutils.h b/kjsembed/slotutils.h
index 7e5650d6..5119d35f 100644
--- a/kjsembed/slotutils.h
+++ b/kjsembed/slotutils.h
@@ -26,7 +26,7 @@
#include <kjs/object.h>
#include <kjsembed/jsbinding.h>
-class TQObject;
+class TTQObject;
namespace KJS { class Interpreter; }
@@ -60,7 +60,7 @@ public:
SignatureURL, SignatureColor, SignaturePoint, SignatureRect,
SignatureSize, SignaturePixmap, SignatureFont, SignatureImage,
- SignatureQWidget,
+ SignatureTQWidget,
SignatureIntInt, SignatureStringInt, SignatureRectBool,
SignatureStringString, SignatureDateDate, SignatureColorString,
@@ -82,81 +82,81 @@ public:
* Returns the method id for the specified slot signature. If there is no match
* then -1 is returned.
*/
- static int findSignature( const TQString &sig );
+ static int findSignature( const TTQString &sig );
/** Connects the specified signal to the specified slot. */
- static bool connect( TQObject *sender, const char *sig, TQObject *recv, const char *dest );
+ static bool connect( TTQObject *sender, const char *sig, TTQObject *recv, const char *dest );
static KJS::Boolean disconnect( KJS::ExecState *exec, KJS::Object &self,
- TQObject *sender, const char *sig, TQObject *recv, const char *dest );
+ TTQObject *sender, const char *sig, TTQObject *recv, const char *dest );
static KJS::Value invokeSlot( KJS::ExecState *exec, KJS::Object &self, const KJS::List&args,
JSObjectProxyImp *proxyimp );
- /** Returns the value of the QUObject or KJS::Null. */
- static KJS::Value extractValue( KJS::ExecState *exec, QUObject *uo, JSObjectProxy *parent=0 );
-
- /** Implant an int into a QUObject. */
- static void implantInt( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v );
- /** Implant a TQString into a QUObject. */
- static void implantQString( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v );
- /** Implant a bool into a QUObject. */
- static void implantBool( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v );
- /** Implant a double into a QUObject. */
- static void implantDouble( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v );
- /** Implant a C string into a QUObject. */
- static void implantCString( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v );
-
- /** Implant a KURL into a QUObject. */
- static void implantURL( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, KURL *url );
- /** Implant a TQColor into a QUObject. */
- static void implantColor( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQColor *color );
- /** Implant a TQPoint into a QUObject. */
- static void implantPoint( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQPoint *point );
- /** Implant a TQRect into a QUObject. */
- static void implantRect( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQRect *rect );
- /** Implant a TQSize into a QUObject. */
- static void implantSize( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQSize *size );
-
- /** Implant a TQDate into a QUObject. */
- static void implantDate( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQDate *date );
- /** Implant a TQTime into a QUObject. */
- static void implantTime( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQTime *time );
- /** Implant a TQDateTime into a QUObject. */
- static void implantDateTime( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQDateTime *datetime );
- /** Implant a TQPixmap into a QUObject. */
- static void implantPixmap( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v, TQPixmap *pix );
+ /** Returns the value of the TQUObject or KJS::Null. */
+ static KJS::Value extractValue( KJS::ExecState *exec, TQUObject *uo, JSObjectProxy *parent=0 );
+
+ /** Implant an int into a TQUObject. */
+ static void implantInt( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v );
+ /** Implant a TTQString into a TQUObject. */
+ static void implantTQString( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v );
+ /** Implant a bool into a TQUObject. */
+ static void implantBool( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v );
+ /** Implant a double into a TQUObject. */
+ static void implantDouble( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v );
+ /** Implant a C string into a TQUObject. */
+ static void implantCString( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v );
+
+ /** Implant a KURL into a TQUObject. */
+ static void implantURL( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, KURL *url );
+ /** Implant a TTQColor into a TQUObject. */
+ static void implantColor( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQColor *color );
+ /** Implant a TTQPoint into a TQUObject. */
+ static void implantPoint( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQPoint *point );
+ /** Implant a TTQRect into a TQUObject. */
+ static void implantRect( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQRect *rect );
+ /** Implant a TTQSize into a TQUObject. */
+ static void implantSize( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQSize *size );
+
+ /** Implant a TTQDate into a TQUObject. */
+ static void implantDate( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQDate *date );
+ /** Implant a TTQTime into a TQUObject. */
+ static void implantTime( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQTime *time );
+ /** Implant a TTQDateTime into a TQUObject. */
+ static void implantDateTime( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQDateTime *datetime );
+ /** Implant a TTQPixmap into a TQUObject. */
+ static void implantPixmap( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v, TTQPixmap *pix );
/**
* Implant a value proxy into a QUObject. The type specified in the clazz parameter
* must match the type of the proxy'd value for the method to succeed.
*/
- static bool implantValueProxy( KJS::ExecState *exec, QUObject *uo,
- const KJS::Value &v, const TQString &clazz);
+ static bool implantValueProxy( KJS::ExecState *exec, TQUObject *uo,
+ const KJS::Value &v, const TTQString &clazz);
- /** Implant a TQVariant into a QUObject. */
- static bool implantQVariant( KJS::ExecState *exec, QUObject *uo,const KJS::Value &v);
+ /** Implant a TTQVariant into a TQUObject. */
+ static bool implantTQVariant( KJS::ExecState *exec, TQUObject *uo,const KJS::Value &v);
/**
* Implant an opaque proxy into a QUObject. The type specified in the
* clazz parameter must match the type of the proxy'd value for the method
* to succeed.
*/
- static bool implantOpaqueProxy( KJS::ExecState *, QUObject *uo,
- const KJS::Value &v, const TQString &clazz );
+ static bool implantOpaqueProxy( KJS::ExecState *, TQUObject *uo,
+ const KJS::Value &v, const TTQString &clazz );
/**
* Implant an object proxy into a QUObject. The object proxy'd by the specified value
* must inherit the class specified for the converstion to succeed.
*/
- static bool implantObjectProxy( KJS::ExecState *exec, QUObject *uo,
- const KJS::Value &v, const TQString &clazz );
- /** Implant a TQString into a QUObject. */
- static void implantStringList(KJS::ExecState *exec, QUObject *uo,
- const KJS::Value &v, TQStringList *lst );
+ static bool implantObjectProxy( KJS::ExecState *exec, TQUObject *uo,
+ const KJS::Value &v, const TTQString &clazz );
+ /** Implant a TTQString into a TQUObject. */
+ static void implantStringList(KJS::ExecState *exec, TQUObject *uo,
+ const KJS::Value &v, TTQStringList *lst );
- /** Implant a char* into a QUObject. */
- static void implantCharStar( KJS::ExecState *exec, QUObject *uo, const KJS::Value &v );
+ /** Implant a char* into a TQUObject. */
+ static void implantCharStar( KJS::ExecState *exec, TQUObject *uo, const KJS::Value &v );
private:
JSSlotUtils();
@@ -82,81 +82,81 @@ public:
/**
- * Implant a value proxy into a QUObject. The type specified in the clazz parameter
+ * Implant a value proxy into a TQUObject. The type specified in the clazz parameter
* must match the type of the proxy'd value for the method to succeed.
*/
@@ -82,81 +82,81 @@ public:
/**
- * Implant an opaque proxy into a QUObject. The type specified in the
+ * Implant an opaque proxy into a TQUObject. The type specified in the
* clazz parameter must match the type of the proxy'd value for the method
* to succeed.
@@ -82,81 +82,81 @@ public:
/**
- * Implant an object proxy into a QUObject. The object proxy'd by the specified value
+ * Implant an object proxy into a TQUObject. The object proxy'd by the specified value
* must inherit the class specified for the converstion to succeed.
*/